@@ -26,24 +26,26 @@
  * Public functions
  */
 gboolean
-gda_ldap_command_new (Gda_ServerCommand *cmd)
-{
-  return TRUE;
+gda_ldap_command_new (Gda_ServerCommand *cmd) {
+	return TRUE;
 }
 
 Gda_ServerRecordset *
 gda_ldap_command_execute (Gda_ServerCommand *cmd,
-			  Gda_ServerError *error,
-			  const GDA_CmdParameterSeq *params,
-			  gulong *affected,
-			  gulong options)
-{
-  Gda_ServerRecordset* recset = NULL;
-
-  return recset;
+                          Gda_ServerError *error,
+                          const GDA_CmdParameterSeq *params,
+                          gulong *affected,
+                          gulong options) {
+	Gda_ServerRecordset* recset = NULL;
+	
+	switch (gda_server_command_get_type(cmd)) {
+		case GDA_COMMAND_TYPE_TEXT :
+		case GDA_COMMAND_TYPE_TABLE :
+		case GDA_COMMAND_TYPE_STOREDPROCEDURE :
+	}
+	return recset;
 }
 
 void
-gda_ldap_command_free (Gda_ServerCommand *cmd)
-{
+gda_ldap_command_free (Gda_ServerCommand *cmd) {
 }
