@@ -97,6 +97,10 @@ Gda_ServerRecordset* gda_oracle_connection_open_schema (Gda_ServerConnection *cn
 							GDA_Connection_QType t,
 							GDA_Connection_Constraint *constraints,
 							       gint length);
+glong gda_oracle_connection_modify_schema (Gda_ServerConnection *cnc,
+                                   GDA_Connection_QType t,
+                                   GDA_Connection_Constraint *constraints,
+                                   gint length);
 gint gda_oracle_connection_start_logging (Gda_ServerConnection *cnc,
 					  const gchar *filename);
 gint gda_oracle_connection_stop_logging (Gda_ServerConnection *cnc);
