@@ -1,5 +1,5 @@
 /* 
- * $Id: gda-sybase-connection.c,v 1.5 2000/11/21 19:57:13 holger Exp $
+ * $Id: gda-sybase-connection.c,v 1.7 2000/11/27 17:50:27 rodrigo Exp $
  *
  * GNOME DB Sybase Provider
  * Copyright (C) 2000 Rodrigo Moya
@@ -22,8 +22,18 @@
  */
 
 // $Log: gda-sybase-connection.c,v $
+// Revision 1.7  2000/11/27 17:50:27  rodrigo
+// 2000-11-27	Rodrigo Moya <rodrigo@gnome-db.org>
+//
+// 	* added modifySchema method to GDA::Connection interface
+//
+// Revision 1.6  2000/11/27 12:09:13  holger
+// 2000-11-27	Holger Thon <holger.thon@gnome-db.org>
+//
+// 	* added primebase server skeleton
+//
 // Revision 1.5  2000/11/21 19:57:13  holger
-// 2000-11-21 Holger Thon <holger@gidayu.max.uni-duisburg.de>
+// 2000-11-21 Holger Thon <holger.thon@gnome-db.org>
 //
 // 	- Fixed missing parameter in gda-sybase-server
 // 	- Removed ct_diag/cs_diag stuff completly from tds server
@@ -262,6 +272,15 @@ gda_sybase_connection_open_schema (Gda_ServerConnection *cnc,
   return NULL;
 }
 
+glong
+gda_sybase_connection_modify_schema (Gda_ServerConnection *cnc,
+                                   GDA_Connection_QType t,
+                                   GDA_Connection_Constraint *constraints,
+                                   gint length)
+{
+  return -1;
+}
+
 gint
 gda_sybase_connection_start_logging(Gda_ServerConnection *cnc,
                                     const gchar *filename)
