@@ -1,5 +1,5 @@
 /* 
- * $Id: gda-sybase-error.c,v 1.1.1.1 2000/08/10 09:32:38 rodrigo Exp $
+ * $Id: gda-sybase-error.c,v 1.2 2000/12/14 13:10:01 bansz Exp $
  * 
  * GNOME DB Sybase Provider
  * Copyright (C) 2000 Rodrigo Moya
@@ -22,6 +22,9 @@
  */
 
 // $Log: gda-sybase-error.c,v $
+// Revision 1.2  2000/12/14 13:10:01  bansz
+// Typo fix
+//
 // Revision 1.1.1.1  2000/08/10 09:32:38  rodrigo
 // First version of libgda separated from GNOME-DB
 //
@@ -415,7 +418,7 @@ gda_sybase_messages_handle_csmsg(Gda_ServerError      *error,
   if (msgcnt > 1) {
     gda_log_message(_("Fetching %d cslib messages"), msgcnt);
   } else {
-    gda_log_message(_("Fetchong %d cslib message"), msgcnt);
+    gda_log_message(_("Fetching %d cslib message"), msgcnt);
   } 
 #endif
 	
