@@ -1,5 +1,5 @@
 /* 
- * $Id: gda-sybase.h,v 1.1.1.1 2000/08/10 09:32:39 rodrigo Exp $
+ * $Id: gda-sybase.h,v 1.2 2000/10/19 19:01:37 reinhard Exp $
  *
  * GNOME DB sybase Provider
  * Copyright (C) 2000 Rodrigo Moya
@@ -37,4 +37,19 @@
 #include "gda-sybase-recordset.h"
 #include "gda-sybase-types.h"
 
+#ifdef ENABLE_NLS
+#  include <libintl.h>
+#  define _(String) gettext (String)
+#  define N_(String) (String)
+#else
+/* Stubs that do something close enough.  */
+#  define textdomain(String)
+#  define gettext(String) (String)
+#  define dgettext(Domain,Message) (Message)
+#  define dcgettext(Domain,Message,Type) (Message)
+#  define bindtextdomain(Domain,Directory)
+#  define _(String) (String)
+#  define N_(String) (String)
+#endif
+
 #endif
