@@ -1,5 +1,5 @@
 /* 
- * $Id: main-tds.c,v 1.2 2000/11/27 17:50:28 rodrigo Exp $
+ * $Id: main-tds.c,v 1.3 2000/12/18 15:32:15 rodrigo Exp $
  * 
  * GNOME DB tds Provider
  * Copyright (C) 2000 Rodrigo Moya
@@ -65,7 +65,7 @@ main (gint argc, gchar *argv[])
   gda_server_init("gda-tds-srv", VERSION, argc, argv);
 
   /* register the server implementation */
-  server_impl = gda_server_impl_new("OAFIID:gda-tds:87cd7ac2-c89d-436c-bf39-7146d2fb0f9e",
+  server_impl = gda_server_impl_new("OAFIID:GNOME_GDA_Provider_TDS_ConnectionFactory",
                                     &server_impl_functions);
   if (server_impl)
     {
